@@ -427,7 +427,7 @@ sub instrument_content {
     my $content = Template::Declare->buffer->pop;
 
     unless ( $seen_title ) {
-        $self->render_title_inpage;
+        $self->render_title_inpage( $self->_title );
     }
 
     Template::Declare->buffer->append( $content );
@@ -452,16 +452,12 @@ sub render_content {
 
 =head3 render_doctype
 
-Renders default doctype - XHTML 1.0 Strict.
+Renders default doctype (HTML5) and opening C<< <html> >> tag
 
 =cut
 
 sub render_doctype {
-    outs_raw(
-        '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"'
-        .' "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'. "\n"
-        .'<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">'. "\n"
-    );
+    outs_raw("<!DOCTYPE html>\n<html>\n");
     return '';
 }
 
@@ -542,8 +538,10 @@ Called from L</render_page>.
 =cut
 
 sub render_navigation {
+    my $self = shift;
+    my @args = @_;
     div { attr { id => "navigation" };
-        Jifty->web->navigation->render_as_menu;
+        Jifty->web->navigation->render_as_menu(@args);
     };
     return '';
 }
